==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RelativeStrengthIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RelativeStrengthIndexIndicatorDescription } from "./RelativeStrengthIndexIndicatorDescription";
/**
 * @hidden
 */
export let RelativeStrengthIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class RelativeStrengthIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (RelativeStrengthIndexIndicatorDescriptionMetadata.a == null) {
                RelativeStrengthIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RelativeStrengthIndexIndicatorDescriptionMetadata.c(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
            }
            if (a.j(RelativeStrengthIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            RelativeStrengthIndexIndicatorDescriptionMetadata.b(a);
            a.aa("RelativeStrengthIndexIndicator", () => new RelativeStrengthIndexIndicatorDescription());
            a.z("RelativeStrengthIndexIndicator", RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
    }
    RelativeStrengthIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(RelativeStrengthIndexIndicatorDescriptionMetadata, 'RelativeStrengthIndexIndicatorDescriptionMetadata');
    RelativeStrengthIndexIndicatorDescriptionMetadata.a = null;
    return RelativeStrengthIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RelativeStrengthIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { RelativeStrengthIndexIndicatorDescription } from "./RelativeStrengthIndexIndicatorDescription";
/**
 * @hidden
 */
export let RelativeStrengthIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class RelativeStrengthIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (RelativeStrengthIndexIndicatorDescriptionMetadata.a == null) {
                RelativeStrengthIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RelativeStrengthIndexIndicatorDescriptionMetadata.c(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(RelativeStrengthIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            RelativeStrengthIndexIndicatorDescriptionMetadata.b(a);
            a.ac("RelativeStrengthIndexIndicator", () => new RelativeStrengthIndexIndicatorDescription());
            a.ab("RelativeStrengthIndexIndicator", RelativeStrengthIndexIndicatorDescriptionMetadata.a);
        }
    }
    RelativeStrengthIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(RelativeStrengthIndexIndicatorDescriptionMetadata, 'RelativeStrengthIndexIndicatorDescriptionMetadata');
    RelativeStrengthIndexIndicatorDescriptionMetadata.a = null;
    return RelativeStrengthIndexIndicatorDescriptionMetadata;
})();
